@@ -2,7 +2,8 @@ from copy import copy
 
 class Settings:
     def __init__(self, fps, width, height, default_pypen_name, _is_executing_with_python,
-                 _user_has_start, _user_has_update, fill_color, stroke_color, stroke_width):
+                 _user_has_start, _user_has_update, fill_color, stroke_color, stroke_width,
+                 _shape_begun, _starting_point):
         self.fps = fps
         self.width = width
         self.height = height
@@ -15,6 +16,9 @@ class Settings:
         self._user_has_start = _user_has_start
         self._user_has_update = _user_has_update
 
+        self._shape_begun = False
+        self._starting_point = None
+
 
 settings = Settings(width=640,
                     height=480,
@@ -26,6 +30,9 @@ settings = Settings(width=640,
 
                     _is_executing_with_python=False,
                     _user_has_start=True,
-                    _user_has_update=True)
+                    _user_has_update=True,
+
+                    _shape_begun=False,
+                    _starting_point=None)
 
 default_settings = copy(settings)
